==> FHLBBS-4.2.tgz: wbbs/showout.c <==
#include "cgic.h"
#include "wbbs.c"

FILE *fptr1,*fptr2;
char buf1[200];




int cgiMain() {
   char *foo, path1[100];
   char *ptr;
   time_t t1;
   char *pt1,*pt2;
   int len1, fd, numposts, i,j;
   signed int numarticle, filecount, fd1;
   int targetdir;
   int fileno,fileok=0;
   FILE *fp;
   cgiFormInteger("TARGETDIR",&targetdir,0);
   switch (targetdir)
    {
        /***** /home/bbs/etc ***/
      case 1 :  
                cgiFormInteger("FILENO",&fileno,0);
                switch(fileno)
                {
                    case 1 : fileok=1;
                             sprintf(path1,BBSHOME "/etc/today");break;
                    case 2 : fileok=1;
                             sprintf(path1,BBSHOME "/etc/wtoday");break;
                    case 3 : fileok=1;
                             sprintf(path1,BBSHOME "/etc/yesterday");break;
                    case 4 : fileok=1;
                             sprintf(path1,BBSHOME "/etc/wyesterday");break;
                    case 5 : fileok=1;
                             sprintf(path1,BBSHOME "/etc/day");break;
                    case 6 : fileok=1;
                             sprintf(path1,BBSHOME "/etc/week");break;
                    case 7 : fileok=1;
                             sprintf(path1,BBSHOME "/etc/month");break;
                    case 8 : fileok=1;
                             sprintf(path1,BBSHOME "/etc/year");break;
                    case 9 : fileok=1;
                             sprintf(path1,BBSHOME "/etc/topusr");break;
                    case 10: fileok=1;
                             sprintf(path1,BBSHOME "/note.ans");break;
                }
                break;

    }
    if (fileok)
    {
        cgiHeaderContentType("text/html");
        if (fp=fopen(path1,"r")) pfile(fp);
    }
    fclose(fp);
   return 0;
}

==> FHLBBS-5.3.tgz: wbbs/showout.c <==
#include "cgic.h"
#include "wbbs.c"

FILE *fptr1,*fptr2;
char buf1[200];




int cgiMain() {
   char *foo, path1[100];
   char *ptr;
   time_t t1;
   char *pt1,*pt2,xuserid[IDLEN+1];
   int len1, fd, numposts, i,j;
   signed int numarticle, filecount, fd1;
   int targetdir;
   int fileno,fileok=0;
   FILE *fp;
   cgiFormInteger("TARGETDIR",&targetdir,0);
   switch (targetdir)
    {
        /***** /home/bbs/etc ***/
      case 1 :  
                cgiFormInteger("FILENO",&fileno,0);
                switch(fileno)
                {
                    case 1 : fileok=1;
                             sprintf(path1,BBSHOME "/etc/today");break;
                    case 2 : fileok=1;
                             sprintf(path1,BBSHOME "/etc/wtoday");break;
                    case 3 : fileok=1;
                             sprintf(path1,BBSHOME "/etc/yesterday");break;
                    case 4 : fileok=1;
                             sprintf(path1,BBSHOME "/etc/wyesterday");break;
                    case 5 : fileok=1;
                             sprintf(path1,BBSHOME "/etc/day");break;
                    case 6 : fileok=1;
                             sprintf(path1,BBSHOME "/etc/week");break;
                    case 7 : fileok=1;
                             sprintf(path1,BBSHOME "/etc/month");break;
                    case 8 : fileok=1;
                             sprintf(path1,BBSHOME "/etc/year");break;
                    case 9 : fileok=1;
                             sprintf(path1,BBSHOME "/etc/topusr");break;
                    case 10: fileok=1;
                             sprintf(path1,BBSHOME "/note.ans");break;
                }
                break;
	case 2 : /*** cuser.userid ***/
		fileok=1;
		cgiFormStringNoNewlines("USERID", xuserid, IDLEN+1);
                sprintf(path1,BBSHOME "/home/%s/%s",xuserid,fn_plans);break;
    }
    if (fileok)
    {
        cgiHeaderContentType("text/html");
        if (fp=fopen(path1,"r")) 
  	{
	  pfile(fp);
    	  fclose(fp);
	}
	else
	 fprintf(cgiOut,"SoӸ!");
    }
   return 0;
}
